SFTP Backend — PyRemoteData 0.0.38 documentation

Skip to content

# SFTP Backend

## Description

This module provides a pythonic interface for downloading files from a remote directory using the SFTP protocol.

The main functionality of this package is provided through the use of the ImplicitMount, IOHandler and RemotePathIterator classes:

- The ImplicitMount class provides a low-level wrapper for the LFTP shell, which is used to communicate with the remote directory, and should only be used directly by advanced users.

- The IOHandler class provides a high-level wrapper for the ImplicitMount class, which provides human-friendly methods for downloading files from a remote directory without the need to have technical knowledge on how to use LFTP.

- The RemotePathIterator class provides a high-level wrapper for the IOHandler class, and handles asynchronous streaming of files from a remote directory to a local directory using thread-safe buffers.

### Contents

Contents:

- ImplicitMount
- IOHandler
- RemotePathIterator